{ ===================================================================
     Hutmil File Component for Delphi - Copyright 1998, Peter Jukel
  ===================================================================
      Version: 1.0b (First beta)

  Distribution:
    This component is freeware.  It is provided "AS IS".  This first
    beta release is available, just to allow authors to include
    basic Hutmil file handling in their programs.  You may only change
    this component with prior permission from Peter Jukel.  You
    e-mail me at hutmil@usa.net. You may not redistribute this component
    in any way without prior permission from Peter Jukel.

    Please report bugs to hutmil@usa.net.

  Hutmil File component for Delphi includes the following functions/
  procedures/properties:

  Property FileQueue: TStrings read+write.  This is the list of files
    in the queue.  When you open a queue using the method Open (FileName),
    all the files in the queue are added to FileQueue.
  Procedure Save (FileName: string).  This procedures saves the files
    in FileQueue to FileName. It is recommended that you use the .HMQ
    file extension (HutMil Queue).
  Function Open (FileName: string)  This function opens the
    file FileName, and returns the files in the queue.  It also
    puts all the files in the queue into FileQueue.  }
unit HutFile;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Inifiles;

type
  THutFile = class(TComponent)
  private
    { Private declarations }
    FFiles: TStrings;
    procedure AddFiles (Value: TStrings);
    function GetFiles: TStrings;
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Save (FileName: String);
    function Open (FileName: String): TStrings;
  published
    { Published declarations }
    property FileQueue: TStrings read GetFiles write AddFiles;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Md3', [THutFile]);
end;

constructor THutFile.Create(AOwner: TComponent);
begin
  inherited Create (AOwner);
  FFiles := TStringList.Create;
end;

destructor THutFile.Destroy;
begin
  FFiles.Free;
  inherited Destroy;
end;

function THutFile.GetFiles: TStrings;
begin
  Result := FFiles;
end;

procedure THutFile.AddFiles (Value: TStrings);
begin
  FFiles.Assign (Value);
end;

procedure THutFile.Save (FileName: String);
var
  I: Integer;
  IniFile: TIniFile;
begin
  IniFile := TIniFile.Create (FileName);
  IniFile.WriteString ('INFO', 'VERSION', '1');
  IniFile.WriteString ('INFO', 'NOOFFILES', IntToStr (FFiles.Count));

  // Add all files in queue to file.
  for I := 0 to FFiles.Count - 1 do
  begin
    IniFile.WriteString ('FILES', IntToStr (I + 1), FFiles.Strings[I]);
  end;
end;

function THutFile.Open (FileName: String): TStrings;
var
  I: Integer;
  IniFile: TIniFile;
begin
  IniFile := TIniFile.Create (FileName);
  // Clear current contents of queue.
  FFiles.Clear;
  for I := 0 to StrToInt (IniFile.ReadString ('INFO', 'NOOFFILES', '')) - 1 do
  begin
    FFiles.Add (IniFile.ReadString ('FILES', IntToStr (I + 1), ''));
  end;
  Result := FFiles;
end;
end.
